Index: third_party/WebKit/Source/web/WebLocalFrameImpl.h |
diff --git a/third_party/WebKit/Source/web/WebLocalFrameImpl.h b/third_party/WebKit/Source/web/WebLocalFrameImpl.h |
index 06167122d3cb9a07ea20e5af9469a77a211ba2b1..4ac184f3a9b3b1f10c304eac18bed3e1b6eb8e87 100644 |
--- a/third_party/WebKit/Source/web/WebLocalFrameImpl.h |
+++ b/third_party/WebKit/Source/web/WebLocalFrameImpl.h |
@@ -180,6 +180,7 @@ class WEB_EXPORT WebLocalFrameImpl final |
bool executeCommand(const WebString&) override; |
bool executeCommand(const WebString&, const WebString& value) override; |
bool isCommandEnabled(const WebString&) const override; |
+ void setTextCheckClient(WebTextCheckClient*) override; |
void enableSpellChecking(bool) override; |
bool isSpellCheckingEnabled() const override; |
void replaceMisspelledRange(const WebString&) override; |
@@ -405,6 +406,7 @@ class WEB_EXPORT WebLocalFrameImpl final |
static void selectWordAroundPosition(LocalFrame*, VisiblePosition); |
TextCheckerClient& textCheckerClient() const; |
+ WebTextCheckClient* textCheckClient() const { return m_textCheckClient; } |
TextFinder* textFinder() const; |
// Returns the text finder object if it already exists. |
@@ -426,7 +428,6 @@ class WEB_EXPORT WebLocalFrameImpl final |
void setContextMenuNode(Node* node) { m_contextMenuNode = node; } |
void clearContextMenuNode() { m_contextMenuNode.clear(); } |
- |
DECLARE_TRACE(); |
private: |
@@ -503,8 +504,9 @@ class WEB_EXPORT WebLocalFrameImpl final |
std::unique_ptr<WebInputMethodControllerImpl> m_inputMethodController; |
// Stores the TextCheckerClient which communicates with SpellCheckProvider. |
Member<TextCheckerClientImpl> m_textCheckerClient; |
+ WebTextCheckClient* m_textCheckClient; |
// Oilpan: WebLocalFrameImpl must remain alive until close() is called. |
// Accomplish that by keeping a self-referential Persistent<>. It is |
@@ -503,8 +504,9 @@ class WEB_EXPORT WebLocalFrameImpl final |
std::unique_ptr<WebInputMethodControllerImpl> m_inputMethodController; |
- // Stores the TextCheckerClient which communicates with SpellCheckProvider. |
+ // Stores the TextCheckerClient to bridge SpellChecker and WebTextCheckClient. |
Member<TextCheckerClientImpl> m_textCheckerClient; |